@@ -57,15 +57,16 @@ def sync_stream(config, state, stream):
             LOGGER.info("Clearing state because stream has aged out")
             state.get('bookmarks', {}).pop(table_name)
 
-        if not singer.get_bookmark(state, table_name, 'initial_full_table_complete'):
-            msg = 'Must complete full table sync before replicating from dynamodb streams for %s'
-            LOGGER.info(msg, table_name)
+        # if not singer.get_bookmark(state, table_name, 'initial_full_table_complete'):
+        #     msg = 'Must complete full table sync before replicating from dynamodb streams for %s'
+        #     LOGGER.info(msg, table_name)
 
-            state = log_based.get_initial_bookmarks(config, state, table_name)
-            singer.write_state(state)
+        #     state = log_based.get_initial_bookmarks(config, state, table_name)
+        #     singer.write_state(state)
 
-            rows_saved += full_table.sync(config, state, stream)
+        #     rows_saved += full_table.sync(config, state, stream)
 
+#without any full row count just runing log based sync on empty state
         rows_saved += log_based.sync(config, state, stream)
     else:
         LOGGER.info('Unknown replication method: %s for stream: %s', replication_method, table_name)
