@@ -80,13 +80,13 @@ def get_shard_records(streams_client, stream_arn, shard, sequence_number):
 
 def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projection, deserializer, table_name, stream_version, state):
     seq_number = seq_number_bookmarks.get(shard['ShardId'])
-
+    
     rows_synced = 0
 
     for record in get_shard_records(streams_client, stream_arn, shard, seq_number):
         LOGGER.info("Record got here  : %s",record)
         if record['dynamodb']['SequenceNumber']==seq_number :
-            LOGGER.info("Skipping sync of shard %s as no records updated")
+            LOGGER.info("Skipping sync of shard %s as no records updated",shard['ShardId'])
             continue
         if record['eventName'] == 'REMOVE':
             record_message = deserializer.deserialize_item(record['dynamodb']['Keys'])
@@ -112,11 +112,13 @@ def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projecti
 
         seq_number_bookmarks[shard['ShardId']] = record['dynamodb']['SequenceNumber']
         state = singer.write_bookmark(state, table_name, 'shard_seq_numbers', seq_number_bookmarks)
-
+        LOGGER.info('get state updated here  : %s',state)
         # Every 100 rows write the state
         if rows_synced % 100 == 0:
             singer.write_state(state)
 
+    LOGGER.info('written state in file : %s',state)
+    
     singer.write_state(state)
     return rows_synced
 
@@ -189,7 +191,7 @@ def sync(config, state, stream):
     if not seq_number_bookmarks:
         seq_number_bookmarks = {}
 
-
+    LOGGER.info("got these sequence numbers : %s ",seq_number_bookmarks)
     # Get the list of closed shards which we have fully synced. These
     # are removed after performing a sync and not seeing the shardId
     # returned by get_shards() because at that point the shard has been
@@ -207,7 +209,8 @@ def sync(config, state, stream):
 
     for shard in get_shards(streams_client, stream_arn):
         found_shards.append(shard['ShardId'])
-        # Only sync shards which we have not fully synced already    
+        # Only sync shards which we have not fully synced already 
+        LOGGER.info("got seq number bookmarks before sync_shard:%s",seq_number_bookmarks)   
         rows_synced += sync_shard(shard, seq_number_bookmarks,
                                     streams_client, stream_arn, projection, deserializer,
                                     table_name, stream_version, state)
@@ -219,6 +222,7 @@ def sync(config, state, stream):
         if seq_number_bookmarks.get(shard['ShardId']):
             seq_number_bookmarks.pop(shard['ShardId'])
             state = singer.write_bookmark(state, table_name, 'shard_seq_numbers', seq_number_bookmarks)
+        LOGGER.info("got seq number bookmarks after sync_shard:%s",seq_number_bookmarks)   
 
         singer.write_state(state)
 
